@@ -88,6 +88,26 @@ satisfy_remote_cran <- function(resolution, candidate, config, ...) {
   TRUE
 }
 
+installedok_remote_cran <- function(installed, solution, config, ...) {
+
+  if (solution$platform != "source") {
+    # Binary packages are simple. We need to match `$build` to make sure
+    # that we are installing the same build.
+    identical(installed$package, solution$package) &&
+      identical(installed$version, solution$version) &&
+      (identical(installed[["platform"]], solution[["platform"]]) ||
+       identical(installed[["platform"]], "*")) &&
+      identical(installed[["built"]], solution[["built"]])
+
+  } else {
+    # Source packages are different, because only the installed one has a
+    # 'Built' field. So we require `Repository == "CRAN"` for these.
+    identical(installed$package, solution$package) &&
+      identical(installed$version, solution$version) &&
+      identical(installed[["repository"]], "CRAN")
+  }
+}
+
 ## ----------------------------------------------------------------------
 ## Internal functions
 
