@@ -34,6 +34,11 @@ satisfy_remote_installed <- function(resolution, candidate,
   TRUE
 }
 
+installedok_remote_installed <- function(installed, solution, config, ...) {
+  # Keep the plan, we were already using the installed package
+  FALSE
+}
+
 ## ----------------------------------------------------------------------
 ## Internal functions
 
@@ -48,36 +53,31 @@ type_installed_rx <- function() {
 }
 
 make_installed_cache <- function(library, packages = NULL, priority = NULL) {
-  pkgs <- packages %||% list.files(library, pattern = "^[a-zA-Z]")
-  meta <- drop_nulls(lapply_with_names(pkgs, function(pkg) {
-    tryCatch(
-      suppressWarnings(
-        readRDS(file.path(library, pkg, "Meta", "package.rds"))
-      ),
-      error = function(e) NULL)
-  }))
+  inst <- pkgcache::parse_installed(
+    library = library,
+    priority = priority,
+    lowercase = TRUE,
+    reencode = FALSE
+  )
 
-  all_fields <- unique(unlist(lapply(
-    meta, function(x) names(x$DESCRIPTION))))
-  fields <- unique(c(
+  all_fields <- names(inst)
+  fields <- tolower(unique(c(
     "Package", "Title", "Version", "Depends", "Suggests", "Imports",
     "LinkingTo", "Enhances", "Built", "MD5sum", "NeedsCompilation",
     "Platform", "License", "Priority", "Repository", "biocViews",
-    grep("^Remote", all_fields, value = TRUE),
-    grep("^Config/Needs/", all_fields, value = TRUE)
-  ))
+    grep("^remote", all_fields, value = TRUE),
+    grep("^config/needs/", all_fields, value = TRUE)
+  )))
 
-  ret <- matrix(NA_character_, nrow = length(meta), ncol = length(fields))
-  colnames(ret) <- tolower(fields)
-  for (i in seq_along(meta)) ret[i,] <- meta[[i]]$DESCRIPTION[fields]
-
-  if (!is.null(priority)) {
-    keep <- ret[, "priority"] %in% priority
-    ret <- ret[keep, , drop = FALSE]
-    meta <- meta[keep]
+  miss <- setdiff(fields, names(inst))
+  for (nm in miss) {
+    inst[[nm]] <- NA_character_
   }
 
-  pkgs <- as_tibble(ret)
+  pkgs <- inst[, names(inst) %in% fields]
+
+  # Called `sysreqs` in pkgcache, so we call it the same here
+  pkgs$sysreqs <- inst[["systemrequirements"]] %||% rep(NA_character_, nrow(pkgs))
 
   if (nrow(pkgs) == 0) {
     pkgs$ref <- character()
@@ -86,9 +86,29 @@ make_installed_cache <- function(library, packages = NULL, priority = NULL) {
   }
   pkgs$type <- rep("installed", nrow(pkgs))
   pkgs$status <- rep("OK", nrow(pkgs))
-  pkgs$rversion <- unname(vcapply(meta, function(x) as.character(x$Built$R)))
-  pkgs$platform <- unname(vcapply(meta, function(x) x$Built$Platform))
+  built <- parse_built(inst$built)
+  pkgs$rversion <- built$R
+  pkgs$platform <- built$Platform
+
+  # This is usually a broken installation, but 'Built' is also missing
+  # for the core translations package
+  pkgs$rversion[is.na(pkgs$rversion)] <- current_r_version()
+  pkgs$platform[is.na(pkgs$platform)] <- current_r_platform()
+
+  # On Windows, we need to check the Archs field
+  winbin <- pkgs$platform != "" &
+    !is.na(built$OStype) &
+    built$OStype == "windows"
+  if (any(winbin)) {
+    archs <- gsub(" ", "", inst$archs[winbin])
+    pkgs$platform[winbin] <- ifelse(
+      is.na(archs) | archs %in% c("i386,x64", "x64,i386"),
+      "i386+x86_64-w64-mingw32",
+      pkgs$platform[winbin]
+    )
+  }
   pkgs$platform[pkgs$platform == ""] <- "*"
+
   pkgs$sources <- replicate(nrow(pkgs), character(), simplify = FALSE)
   pkgs$needscompilation <- ifelse(
     is.na(pkgs$needscompilation), NA,
@@ -192,7 +212,7 @@ resolve_installed  <- function(cache, remotes, direct, dependencies) {
   cols <- c(
     "ref", "type", "status", "package", "version", "license",
     "needscompilation", "priority", "md5sum", "platform", "rversion",
-    "sources", "built", "deps", "repotype")
+    "sources", "built", "deps", "repotype", "sysreqs")
   res <- pkgs[pkgs$package %in% packages, cols]
   repotype <- pkgs$repotype[pkgs$package %in% packages]
 
@@ -225,3 +245,14 @@ get_installed_metadata <- function(tab) {
   }
   meta
 }
+
+parse_built <- function(x) {
+  xp <- strsplit(x, ";", fixed = TRUE)
+  data.frame(
+    stringsAsFactors = FALSE,
+    R        = trimws(vapply(xp, "[", character(1), 1)),
+    Platform = trimws(vapply(xp, "[", character(1), 2)),
+    Date     = trimws(vapply(xp, "[", character(1), 3)),
+    OStype   = trimws(vapply(xp, "[", character(1), 4))
+  )
+}
